@@ -1,7 +1,7 @@
 package WWW::PAUSE::Simple;
 
 our $DATE = '2017-06-28'; # DATE
-our $VERSION = '0.40'; # VERSION
+our $VERSION = '0.41'; # VERSION
 
 use 5.010001;
 use strict;
@@ -53,10 +53,11 @@ _
     # 2016-07-13 - for a few months now, PAUSE has been giving random 500 errors
     # when uploading. i'm defaulting to a retries=2.
     # 2017-06-28 - increase default to retries=7.
+    # 2017-06-28 - tone down retries to 5.
     retries => {
         summary => 'Number of retries when received 5xx HTTP error from server',
         schema  => 'int*',
-        default => 7,
+        default => 5,
         tags    => ['common'],
     },
     retry_delay => {
@@ -152,6 +153,9 @@ sub _request {
     require HTTP::Request::Common;
 
     my %args = @_;
+    # XXX schema
+    $args{retries} //= 5;
+    $args{retry_delay} //= 3;
 
     # set default for username and password from ~/.pause
     my $username = $args{username};
@@ -857,7 +861,7 @@ WWW::PAUSE::Simple - An API for PAUSE
 
 =head1 VERSION
 
-This document describes version 0.40 of WWW::PAUSE::Simple (from Perl distribution WWW-PAUSE-Simple), released on 2017-06-28.
+This document describes version 0.41 of WWW::PAUSE::Simple (from Perl distribution WWW-PAUSE-Simple), released on 2017-06-28.
 
 =head1 SYNOPSIS
 
@@ -905,7 +909,7 @@ not yet supported.
 
 Protect some files/wildcard patterns from delete/cleanup.
 
-=item * B<retries> => I<int> (default: 7)
+=item * B<retries> => I<int> (default: 5)
 
 Number of retries when received 5xx HTTP error from server.
 
@@ -991,7 +995,7 @@ not yet supported.
 
 Protect some files/wildcard patterns from delete/cleanup.
 
-=item * B<retries> => I<int> (default: 7)
+=item * B<retries> => I<int> (default: 5)
 
 Number of retries when received 5xx HTTP error from server.
 
@@ -1071,7 +1075,7 @@ PAUSE password.
 If unset, default value will be searched from C<~/.pause>. Encrypted C<.pause> is
 not yet supported.
 
-=item * B<retries> => I<int> (default: 7)
+=item * B<retries> => I<int> (default: 5)
 
 Number of retries when received 5xx HTTP error from server.
 
@@ -1133,7 +1137,7 @@ PAUSE password.
 If unset, default value will be searched from C<~/.pause>. Encrypted C<.pause> is
 not yet supported.
 
-=item * B<retries> => I<int> (default: 7)
+=item * B<retries> => I<int> (default: 5)
 
 Number of retries when received 5xx HTTP error from server.
 
@@ -1191,7 +1195,7 @@ PAUSE password.
 If unset, default value will be searched from C<~/.pause>. Encrypted C<.pause> is
 not yet supported.
 
-=item * B<retries> => I<int> (default: 7)
+=item * B<retries> => I<int> (default: 5)
 
 Number of retries when received 5xx HTTP error from server.
 
@@ -1252,7 +1256,7 @@ PAUSE password.
 If unset, default value will be searched from C<~/.pause>. Encrypted C<.pause> is
 not yet supported.
 
-=item * B<retries> => I<int> (default: 7)
+=item * B<retries> => I<int> (default: 5)
 
 Number of retries when received 5xx HTTP error from server.
 
@@ -1323,7 +1327,7 @@ PAUSE password.
 If unset, default value will be searched from C<~/.pause>. Encrypted C<.pause> is
 not yet supported.
 
-=item * B<retries> => I<int> (default: 7)
+=item * B<retries> => I<int> (default: 5)
 
 Number of retries when received 5xx HTTP error from server.
 
@@ -1399,7 +1403,7 @@ PAUSE password.
 If unset, default value will be searched from C<~/.pause>. Encrypted C<.pause> is
 not yet supported.
 
-=item * B<retries> => I<int> (default: 7)
+=item * B<retries> => I<int> (default: 5)
 
 Number of retries when received 5xx HTTP error from server.
 
